/**
 * @package css-modules-types-loader
 * @license MIT
 * @version 0.6.6
 * @author nuintun <nuintun@qq.com>
 * @description A webpack loader that dynamically generates TypeScript typings for CSS modules from css-loader.
 * @see https://github.com/nuintun/css-modules-types-loader#readme
 */

'use strict';

const promises = require('node:fs/promises');
const utils = require('./utils.cjs');

/**
 * @module generate
 */
async function generate({ eol, path, banner, content }) {
  const typings = utils.generateTypings(content, banner, eol);
  if (typings) {
    await promises.writeFile(path, typings);
    return { path, action: 'generate' /* Action.GENERATE */ };
  }
  await utils.removeFile(path);
  return { path, action: 'remove' /* Action.REMOVE */ };
}

module.exports = generate;
